/*
**
****************************************************************************
**
**
**             Copyright (c) 2007 - Atmel Corporation
**             Proprietary Information
**
** Project    	: ATMEGA88 + ATA6832 High Temperature
** Module     	: High_temp_BLDC_board.h 
** Description	: I/O MACRO 
**                To be used with "High temperature BLDC board" 
**
** Version :     Date:         Author:      Comment:
**    1.0        23.01.2007    F.G.          Creation          

**
**
**
** LICENSE - 
**
** ATMEL - 2007
** All software programs are provided 'as is' without warranty of any kind:
** Atmel does not state the suitability of the provided materials for any 
** purpose. Atmel hereby disclaim all warranties and conditions with regard
** to the provided software, including all implied warranties, fitness for
** a particular purpose, title and non-infringement.In no event will Atmel
** be liable for any indirect or consequential damages or any damages
** whatsoever resulting from the usage of the software program.
****************************************************************************
**
*/

#ifndef _BOARD_H
#define _BOARD_H

/*_____ D E F I N I T I O N S ______________________________________________*/


//----------------------------------------------------------------------//
//                     MCU PORT DECLARATION                             //    
//----------------------------------------------------------------------//


//PORTB
#define _LIN_RXD_A            0x01  //PB0(ICP1/CLKO/PCINT0)
#define _PWM                  0x02  //PB1(OC1A/PCINT1)
#define _SPI_SS               0x04  //PB2(OC1B/SS/PCINT2)
#define _MOSI                 0x08  //PB3(MOSI/OC2A/PCINT3)
#define _MISO                 0x10  //PB4(MISO/PCINT4)
#define _SCK                  0x20  //PB5(SCK/PCINT5)
#define _PB6                  0x40  //PB6(TOSC1/XTALL1/PCINT6)
#define _PB7                  0x80  //PB7(TOSC2/XTAL2/PCINT7)

//PORTC
#define _SPEED_SET            0x01  //PC0(ADC0/PCINT8)
#define _PC1                  0x02  //PC1(ADC1/PCINT9)
#define _HALL_A               0x04  //PC2(ADC2/PCINT10)
#define _HALL_B               0x08  //PC3(ADC3/PCINT11)
#define _HALL_C               0x10  //PC4(ADC4/SDA/PCINT12)
#define _PC5                  0x20  //PC5(ADC5/SCL/PCINT13)
#define _NRESET               0x40  //PC6(RESET/PCINT14)

//PORTD
#define _LIN_RXD              0x01  //PD0(RXD/PCINT16)
#define _LIN_TXD              0x02  //PD1(TXD/PCINT17)
#define _LIN_SLEEP            0x04  //PD2(INT0/PCINT18)
#define _SWITCH_CCW           0x08  //PD3(INT1/OC2B/PCINT19)
#define _SWITCH_CW            0x10  //PD4(T0/XCK/PCINT20)
#define _GREEN_LED            0x20  //PD5(T1/OC0B/PCINT21)
#define _PD6                  0x40  //PD6(AIN0/OC0A/PCINT22) 
#define _PD7                  0x80  //PD7(AIN1/PCINT2)

//----------------------------------------------------------------------//
//                     MCU SPECIFIC ENABLE/DISABLE MACROS               //    
//----------------------------------------------------------------------//
#define ENABLE_LIN()          (DDRD |= _LIN_SLEEP ,  PORTD |=  _LIN_SLEEP)
#define DISABLE_LIN()         (DDRD |= _LIN_SLEEP ,  PORTD &=~ _LIN_SLEEP)

#define ENABLE_SPI_IO()       (DDRB |=  (_MOSI | _SCK | _SPI_SS), PORTB |= _SPI_SS)
#define DISABLE_SPI_IO()      (DDRB &= ~(_MOSI | _SCK | _SPI_SS))
#define SET_SPI_SS()          (PORTB |=  _SPI_SS)          // Set slave select
#define RESET_SPI_SS()        (PORTB &= ~_SPI_SS)          // Clear slave select

//----------------------------------------------------------------------//
//                     MCU PORT CONFIG MACROS                           //    
//----------------------------------------------------------------------//

#define  CONFIG_PORTB() (DDRB   = _PWM , PORTB =  _LIN_RXD_A | _PWM)
#define  CONFIG_PORTC() (DDRC   = 0x00,  PORTC  = 0x00 )
#define  CONFIG_PORTD() (DDRD   = _LIN_TXD | _LIN_SLEEP | _GREEN_LED , PORTD  = _LIN_TXD | _LIN_RXD | _SWITCH_CCW | _SWITCH_CW)

#define  CONFIG_IO_PORTS() (CONFIG_PORTB(),CONFIG_PORTC() ,CONFIG_PORTD())

//----------------------------------------------------------------------//
//                     MCU OUTPUT SET MACROS                            //    
//----------------------------------------------------------------------//
#define SET_GREEN_LED()             (PORTD  &=  ~_GREEN_LED )

//----------------------------------------------------------------------//
//                     MCU OUTPUT RESET MACROS                          //    
//----------------------------------------------------------------------//
#define RESET_GREEN_LED()           (PORTD  |=  _GREEN_LED )

//----------------------------------------------------------------------//
//                     MCU OUTPUT TOGGLE MACROS                         //    
//----------------------------------------------------------------------//
#define TOGGLE_GREEN_LED()          (PORTD ^= _GREEN_LED )

//----------------------------------------------------------------------//
//                     MCU OUTPUT GET MACROS                            //    
//----------------------------------------------------------------------//
#define GET_SWITCH_CW()             ((PIND & _SWITCH_CW) == 0x00)
#define GET_SWITCH_CCW()            ((PIND & _SWITCH_CCW) == 0x00)


//----------------------------------------------------------------------//
//                     MCU KEYBAORD OR LIN COMMANDS RELATED MACROS      //    
//----------------------------------------------------------------------//

#endif  /* _BOARD_H */



